set more off
set scheme lean1
use scad_original, clear
drop actor1-target2  numberofdeaths location  description additionalinformation
drop if eventtype=="Insurgency/Civil War"

*convert startdate and enddate to startyr and endyr, generate duration in years
gen startyr = ""
replace startyr = substr(startdate,-4,4)
destring startyr, replace
gen endyr = ""
replace endyr = substr(enddate,-4,4)
destring endyr, replace
gen duration = (endyr-startyr) + 1
**expand the observations for events spanning more than a year
expand duration
gen year= startyr
sort countrycode year endyr
bysort countrycode eventid: replace year= startyr[_n-1] + 1 if eventid==eventid[_n-1]
drop eventid

*generate dummy variables for each event, escalated event, location
tabulate eventtype, generate (event)
tabulate escalation, generate (esca)
tabulate locationtype, generate (loct)


*aggregate the 7 location types into urban, rural, and capital. 
**except for location "other major urban area" (loct2), all urban locations include capital
**location "nationwide" (loct5) is coded both as urban and rural, and also as capital
**location "Province/Region Listed, Exact Location Unknown" (loct6) is coded as rural
gen urban=0
gen rural=0
gen capital=0
replace urban=1 if loct1 | loct2 | loct4 | loct5==1
replace rural=1 if loct3 | loct5 | loct6 | loct7==1
replace capital=1 if loct1 | loct4 | loct5==1
replace urban=. if loct8==1
replace rural=. if loct8==1
replace capital=. if loct8==1


*generate variables for when the central gov/regional gov/both/neither was targeted
gen targetcgov=0
replace targetcgov=1 if wasthecentralgovernmentatarget=="Yes"
gen targetrgov=0
replace targetrgov=1 if wasaregionalprovincialorlocalgov=="Yes"
gen targetbothgov=0
gen targetnogov=0
replace targetbothgov=1 if targetcgov==1 & targetrgov==1 
replace targetnogov=1 if targetcgov==0 & targetrgov==0 

*replace the number of participants interval categories with numerical categories
*from 1 to 7. Generate a variable to weight each category. Generate a variable
*giving the weighted value of each observation (this is summed later while collapsing
*the dataset.
gen numpart=.
replace numpart=1 if numberofparticipants=="<10"
replace numpart=2 if numberofparticipants=="10 - 100"
replace numpart=3 if numberofparticipants=="101 - 1,000"
replace numpart=4 if numberofparticipants=="1,001 - 10,000"
replace numpart=5 if numberofparticipants=="10,001 - 100,000"
replace numpart=6 if numberofparticipants=="100,001 - 1,000,000"
replace numpart=7 if numberofparticipants==">1,000,000"

gen numpartweight=.
replace numpartweight=1 if numpart==7
replace numpartweight=7/60 if numpart==6
replace numpartweight=7/500 if numpart==5
replace numpartweight=7/4000 if numpart==4
replace numpartweight=7/30000 if numpart==3
replace numpartweight=7/200000 if numpart==2
replace numpartweight=7/1000000 if numpart==7

gen numpartw=numpart*numpartweight
drop numberofparticipants
drop numpart
drop numpartweight


*generate three separate dummy variables for lethal, nonlethal, no repression
**for the variable represlethal, 0 means: non-lethal repression or no repression
**for the variable represnonlethal, 0 means: lethal repression or no repression
**for the variable represnone, 0 means: lethal repression or non-lethal repression
gen represlethal=0
gen represnonlethal=0
gen represnone=0
replace represlethal=1 if repression=="Lethal"
replace represnonlethal=1 if repression=="Non-Lethal"
replace represnone=1 if repression=="None"

*generate four separate variables for issue type
**issprogov= pro-govt
**isspolitic= elections/democracy/human rights
**issenveduecon= Food/Water/Subsistence/Education/Economy/Economic Resources
**issother= other known categories in SCAD issue list (environmental degradation
**ethnic discrimination, ethnic issues, religious discrimination, religious issues
**foreign affairs/relations, domestic war, violance, terrorism, other)
**if issue is "unkown, not-specified", all issue variables created here are coded missing
gen issprogov=0
replace issprogov=1 if issue1=="Pro-Government" | issue2=="Pro-Government" | issue3=="Pro-Government"
replace issprogov=. if issue1=="Unknown/Not Specified" & issue2=="Unknown/Not Specified" & issue3=="Unknown/Not Specified"
gen isspolitic=0
replace isspolitic=1 if issue1=="Elections" | issue2=="Elections" | issue3=="Elections"
replace isspolitic=1 if issue1=="Human Rights/Democracy" | issue2=="Human Rights/Democracy" | issue3=="Human Rights/Democracy"
replace isspolitic=. if issue1=="Unknown/Not Specified" & issue2=="Unknown/Not Specified" & issue3=="Unknown/Not Specified"
gen issenveduecon=0
replace issenveduecon=1 if issue1=="Food/Water/Subsistence" | issue2=="Food/Water/Subsistence" | issue3=="Food/Water/Subsistence"
replace issenveduecon=1 if issue1=="Education" | issue2=="Education" | issue3=="Education"
replace issenveduecon=1 if issue1=="Economy/Jobs" | issue2=="Economy/Jobs" | issue3=="Economy/Jobs"
replace issenveduecon=1 if issue1=="Economic Resources/Assets" | issue2=="conomic Resources/Assets" | issue3=="conomic Resources/Assets"
replace issenveduecon=. if issue1=="Unknown/Not Specified" & issue2=="Unknown/Not Specified" & issue3=="Unknown/Not Specified"
gen issother=0
replace issother=1 if issprogov==0 & isspolitic==0 & issenveduecon==0
replace issother=. if issue1=="Unknown/Not Specified" & issue2=="Unknown/Not Specified" & issue3=="Unknown/Not Specified"


*
gen flagloc=0
gen loctype="."
replace loctype="urban" if urban==1
replace loctype="rural" if rural==1
replace loctype="capital" if capital==1
local locset "urban rural capital"
foreach x of local locset { 
			replace flagloc=1 if loctype=="`x'"
			replace flagloc=. if loctype=="."
}
*
gen flagiss=0
gen issue="issother"
replace issue="issprogov" if issprogov==1
replace issue="isspolitic" if isspolitic==1
replace issue="issenveduecon" if issenveduecon==1
replace issue="." if issue1=="." & issue2=="." & issue3=="." 
local issset "isspolitic issenveduecon issother"      /* This excludes "pro gov" events */
foreach x of local issset { 
			replace flagiss=1 if issue=="`x'"
			replace flagiss=. if issue=="."
			}
*
gen flagtarg=0
gen target="targetcgov"
replace target="targetrgov" if targetrgov==1
replace target="targetbothgov" if targetbothgov==1
replace target="targetnogov" if targetnogov==1
local targset "targetcgov targetrgov targetbothgov"     /* This excludes events where government wasn't targeted */
foreach x of local targset { 
			replace flagtarg=1 if target=="`x'"
			}
*
gen flagdrop=0
replace flagdrop=1 if flagloc==0 
replace flagdrop=1 if flagiss==0
replace flagdrop=1 if flagtarg==0

drop if flagdrop==1
rename countrycode cowcode
sort cow year
merge cow year using gwfTSCS
tab _merge
keep if _merge==3
gen ss = date(startdate,"MDY")  /* this code is for Stata 12; for Stata 9, use: <gen ss = date(startdate,"mdy")> */
format ss %td			/* this code is for Stata 12; for Stata 9, use: <format ss %d> */
egen cy = concat(cow year)
bysort cy: gen flagdate = ss<=gwf_enddate
keep if flagdate==1
drop flagdate


drop countryname-enddate eventtype-wasaregionalprovincialorlocalgov repression-endyr loct1-loct8  flagloc- flagdrop
order cow year

local variables "durationdays duration event1 event2 event3 event4 event5 event6 event7 event8 event9 event10 esca1 esca2 esca3 esca4 esca5 esca6 esca7 esca8 esca9 esca10 esca11 urban rural capital targetcgov targetrgov targetbothgov targetnogov numpartw represlethal represnonlethal represnone issprogov isspolitic issenveduecon issother"
local i = 1
foreach v of local variables {
 	local call `call' (sum) `v' (count) nonmiss`i' = `v'
 	local ++i
}
*
collapse `call', by(cow year)

local variables "durationdays duration event1 event2 event3 event4 event5 event6 event7 event8 event9 event10 esca1 esca2 esca3 esca4 esca5 esca6 esca7 esca8 esca9 esca10 esca11 urban rural capital targetcgov targetrgov targetbothgov targetnogov numpartw represlethal represnonlethal represnone issprogov isspolitic issenveduecon issother"
local i = 1
quietly foreach v of local variables {
 	replace `v' = . if nonmiss`i' == 0
 	local ++i
}
*

drop nonmiss*

rename durationdays scad_durationdays
rename duration scad_duration
rename event1 scad_antigovvio
rename event2 scad_extragovvio
rename event3 scad_genstrike
rename event4 scad_intragovvio
rename event5 scad_limstrike
rename event6 scad_orgdem
rename event7 scad_orgriot
rename event8 scad_progovvio
rename event9 scad_spondem
rename event10 scad_sponriot
rename esca1 scad_escaantigovvio
rename esca2 scad_escaextragovvio
rename esca3 scad_escagenstrike
rename esca4 scad_escaintragovvio
rename esca5 scad_escalimstrike
rename esca6 scad_escanone
rename esca7 scad_escaorgdem
rename esca8 scad_escaorgriot
rename esca9 scad_escaprogovvio
rename esca10 scad_escaspondem
rename esca11 scad_escasponriot
rename urban scad_urban
rename rural scad_rural
rename capital scad_capital
rename targetcgov scad_targetcgov
rename targetrgov scad_targetrgov
rename targetbothgov scad_targetbothgov
rename targetnogov scad_targetnogov
rename numpartw scad_numpartw
rename represlethal scad_represslethal
rename represnonlethal scad_repressnonlethal
rename represnone scad_repressnone
rename issprogov scad_issprogov
rename isspolitic scad_isspolitic
rename issenveduecon scad_issenveduecon
rename issother scad_issother


label var scad_durationdays "Sum of number of days all events in a country-year lasted"
label var scad_duration "Sum of number of years each event in a country-year lasted between 1990-2011"
label var scad_antigovvio "Number of anti-government violence events"
label var scad_extragovvio "Number of extra-government violence events"
label var scad_genstrike "Number of general strike events"
label var scad_intragovvio "Number of intra-government violence events"
label var scad_limstrike "Number of limited strike events"
label var scad_orgdem "Number of organized demonstration events"
label var scad_orgriot "Number of oranized riot events"
label var scad_progovvio "Number of pro-government riot events"
label var scad_spondem "Number of spontenous demonstration events"
label var scad_sponriot "Number of spontenous riot events"
label var scad_escaantigovvio "Number of events that escalated into anti-government violence"
label var scad_escaextragovvio "Number of events that escalated into extra-government violence"
label var scad_escagenstrike "Number of events that escalated into general strike"
label var scad_escaintragovvio "Number of events that escalated into intra-government violence"
label var scad_escalimstrike "Number of events that escalated into limited strike"
label var scad_escaorgdem "Number of events that escalated into organized demonstration"
label var scad_escaorgriot "Number of events that escalated into oranized riot"
label var scad_escaprogovvio "Number of events that escalated into pro-government riot"
label var scad_escaspondem "Number of events that escalated into spontenous demonstration"
label var scad_escasponriot "Number of events that escalated into spontenous riot"
label var scad_escanon "Number of events that didnot escalete"
label var scad_urban "Number of events taking place in urban locations"
label var scad_rural "Number of events taking place in rural locations"
label var scad_capital "Number of events taking place in the capital city"
label var scad_targetcgov "Number of events targeted towards the central government"
label var scad_targetrgov "Number of events targeted towards a regional government"
label var scad_targetbothgov "Number of events targeted towards both a regional and the central government"
label var scad_targetnogov "Number of events not targeted towards a regional or the central government"
label var scad_numpartw "Weighted sum of number of participant categories for all events in a country-year"
label var scad_represslethal "Number of events during which lethal repression took place"
label var scad_repressnonlethal "Number of events during which non-lethal repression took place"
label var scad_repressnone "Number of events during which no repression took place"
label var scad_issprogov "Number of events involving pro-government issues"
label var scad_isspolitic "Number of events involving elections/democracy/human rights issues"
label var scad_issenveduecon "Number of events involving environment, education, economic issues"
label var scad_issother "Number of events involving other issues"
sort cowcode year
save "scad.dta", replace
