capture program drop two
program define two
	set scheme lean1
	use rugged_data, clear             			/* available at: http://diegopuga.org/data/rugged/  accessed: 4.7.2014 */
	keep soil near_coast country isonum
	gen cowcode= .
	qui do cowcodes
	replace cowcode = 490 if isonum==862  		/* Venezuela */
	replace cowcode = 315 if isonum==203 		/* Czechoslovakia */
	sort cow  
	save two, replace
	use remit_original, clear
	sort year
	merge year using gdpdeflator
	drop _merge
	replace remit_c= remit_c/gdpdeflator
	gen cowcode=.
	qui do cowcodes
	gen remit_world = remit_c if country_name=="High income: OECD"
	egen wyr_remit  = max(remit_world) , by(year)
	egen c = group(country)
	tsset c year
	gen wremit = (wyr)
	drop if cow==.    
	tsset cow year
	gen worldremit = ln(l.wremit) 
	keep cow year worldremit  
	sort cowcode year
	merge cow year using temp
	keep if _merge~=1
	drop _merge
	sort cow year
	merge cow using two
	tab _merge
	drop if _merge==2
	gen dist =  near_coast*soil/10000
	sort cow year
	replace dist = dist[_n-1] if dist[_n-1]~=. & year==2009
	if "$l" == "change" {
		replace dist =  .0523638 if cow==570
	} 
	else if "$l" == "drop" {
		drop if cow==570
	}
	else if "$l" == "" {
	}
	gen remitdist = (worldremit*dist) 
	hist remitdist, bin(100)
	gen sp_remit = sp*remit
	gen sp_remitdist =  ((sp*remitdist))/10
	gen gdp = l.wdi_lgdp
	gen nbr = l.neighbor_geddem >=1  
	gen gr = wdi_lag12
	gen civwar=prio_lconflict_intra>0 if prio_lconflict_intra~=.
	replace civwar = civwar*prio_lconflict_int 
	gen trade = ln(1+l.wdi_tradegdp)
	gen yr = year<=1979
	replace yr = 2 if year<=1984 & year>=1980
	replace yr = 3 if year<=1989 & year>=1985
	replace yr = 4 if year<=1994 & year>=1990
	replace yr = 5 if year<=1999 & year>=1995
	replace yr = 6 if year<=2004 & year>=2000
	replace yr = 7 if year<=2009 & year>=2005
	saveold two, replace
end

global l = "drop"
qui two

* i.yr is a series of dummies variables for five-year time periods *
 
*Reduced form*
tsset cow year
xi: xtreg ged_dem  i.yr ged_time ged_time2 ged_time3  remitdist  sp gdp pop civwar nbr migration  if year>=1975 , cluster(cow) fe 

*Show that treatment occurs in both party and non-party regimes*
xi: qui xtreg remit time time2  ged_time ged_time2 ged_time3 remitdist sp gdp pop civwar nbr migration  if year>=1975 & sp==1, cluster(cow) fe
test remitdist
xi: qui xtreg remit time time2 ged_time ged_time2 ged_time3 remitdist sp gdp pop civwar nbr migration  if year>=1975 & sp==0, cluster(cow) fe
test remitdist
xi: qui xtreg remit i.yr  ged_time ged_time2 ged_time3 remitdist sp gdp pop civwar nbr migration  if year>=1975 & sp==1, cluster(cow) fe
test remitdist
xi: qui xtreg remit i.yr ged_time ged_time2 ged_time3 remitdist sp gdp pop civwar nbr migration  if year>=1975 & sp==0, cluster(cow) fe
test remitdist

*Reported two-stage (no interaction)*
tsset cow year
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit = remitdist) sp gdp pop civwar nbr migration  if year>=1975 , cluster(cow) fe ffirst
est store two2

*Reported first stage*
egen m = count(year) if e(sample), by(cow)
xi: qui xtreg remit  i.yr ged_time ged_time2 ged_time3 remitdist sp gdp pop civwar nbr migration  if e(sample) & m>1, cluster(cow) fe
est store two1 
xi: qui reg remit  i.cow i.yr ged_time ged_time2 ged_time3 remitdist sp gdp pop civwar nbr migration  if e(sample) & m>1 , cluster(cow)
avplot remitdist, mlabel(year)
test remitdist

*Reported two-stage (with interaction)*
xi: qui reg remit i.cow i.yr  ged_time ged_time2 ged_time3 remitdist sp_remitdist sp gdp pop civwar nbr migration  if year>=1975, cluster(cow)
est store first1
xi: qui reg sp_remit i.cow i.yr  ged_time ged_time2 ged_time3 remitdist sp_remitdist sp gdp pop civwar nbr migration  if year>=1975, cluster(cow)
est store first2
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>=1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two3

estout two1 two2 two3 using Table2.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(widstat idp N_clust N) style(tex) replace label starlevels(+ 0.10 * 0.05 ** 0.01) title(Remittances and democratic transition\label{tab2})
estout first1 first2 using TableB1.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(r2 N_clust N) style(tex) replace label starlevels(+ 0.10 * 0.05 ** 0.01) title(Remittances and democratic transition\label{tab2})

*********************************************
*** Autocratic transition models for Appendix B-3 ***
*********************************************
  xi: xtivreg2 ged_dict  i.yr ged_time ged_time2 ged_time3 (remit = remitdist) sp gdp pop civwar nbr migration  if year>=1975 , cluster(cow) fe ffirst
 est store twoA1
 xi: xtivreg2 ged_dict  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>=1975 , cluster(cow) fe ffirst
 lincom remit + sp_remit
 est store twoA2
estout twoA1 twoA2 using TableB3.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(r2 N_clust N) style(tex) replace label starlevels(+ 0.10 * 0.05 ** 0.01) title(Remittances and democratic transition\label{tab2})


*********************************************************
****Democratic transition models for the Appendix B-2****
*********************************************************

*Cluster errors by regime (not country) & include 4 singleton observations dropped in FE estimator*
xi: ivreg2 ged_dem  i.cow i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration if year>=1975, cluster(geddes_case) partial(i.cow i.yr ged_time*) ffirst
lincom remit + sp_remit

*No control variables*
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp    if year>=1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two4

* We are up to 12 reviewers (perhaps someone as reviewed for more than one journal), and each has her/his own set of "Controls" Yeah! *

*No control for migration*
xi: xtivreg2 ged_dem  i.ged_time i.yr (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr if year>=1975 , cluster(cow)   ffirst fe partial(i.ged_time i.yr)
lincom remit + sp_remit
est store two5

*Control for trade*
xi: xtivreg2 ged_dem  i.ged_time i.yr (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration trade    if year>=1975 , cluster(cow)   ffirst fe partial(i.ged_time i.yr)
lincom remit + sp_remit
est store two6

*Control for growth*
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration gr  if year>=1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two7

*Control for growth and protest*
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration protest if year>=1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two8

*More control variables*
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration gr migration protest oil aid kaopen  if year>=1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two9

*linear time trend* 
xi: xtivreg2 ged_dem  time  ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>1975 , cluster(cow) fe ffirst
lincom remit + sp_remit

*quadratic time trend* 
xi: xtivreg2 ged_dem  time time2 ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>1975 , cluster(cow) fe ffirst
lincom remit + sp_remit

*no time trend*
xi: xtivreg2 ged_dem  time ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>1975 , cluster(cow) fe ffirst
lincom remit + sp_remit

*year fixed effects*
xi: xtivreg2 ged_dem  i.year ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two10

*Drop 1975*
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two11

*change Lesotho to S. Africa*
global l = "change"
qui two
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>=1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two12

*keep Lesotho*
global l = "include"
qui two
xi: xtivreg2 ged_dem  i.yr ged_time ged_time2 ged_time3 (remit sp_remit = sp_remitdist remitdist) sp gdp pop civwar nbr migration  if year>=1975 , cluster(cow) fe ffirst
lincom remit + sp_remit
est store two13

estout two4 two5 two6 two7 two8 two9 two10 two11 two12 two13 using TableB2.tex, cells(b(star  fmt(%9.3f)) se(par fmt(%9.2f))) stats(widstat idp N_clust N) style(tex) replace label starlevels(+ 0.10 * 0.05 ** 0.01) title(Remittances and democratic transition\label{tab2})
